@@ -25,13 +25,14 @@ var report = {
 	init: function() {
 		
 		// util.showObject(reportInfo);
-		// console.log('report.init()');
+//		console.log('report.init()');
 		
 		var YE = YAHOO.util.Event;
 		
 		// Init admin drop down menu
-		util.initAdminDropDownMenu();
-		util.initBreadCrumbNav();
+//		util.initAdminDropDownMenu();
+//		util.initBreadCrumbNav();
+		reportsConfigNavbar.init(true);
 		
 		var reportElements = reportInfo.reportElements;
 		var maxReportElements = reportElements.length;
@@ -63,7 +64,7 @@ var report = {
 
 
 			//
-			// init reportLink
+			// Init reportLink
 			//
 
 			var reportLink = o.reportLink;
@@ -73,8 +74,30 @@ var report = {
 			}
 
 			//
+			// Init Customize
 			//
-			// init rows
+
+			var customizeBtn = util.getE(shortReportElementId + ':customize:table');
+			if (customizeBtn != null) {
+				YE.addListener(customizeBtn, 'click', customizeRE.open);
+			}
+
+
+			//
+			// Init Export
+			//
+
+			var exportBtn = util.getE(shortReportElementId + ':export:btn');
+			if (exportBtn != null) {
+				exportBtn.disabled = false;
+				exportBtn.className = 'btn-60';
+				YE.addListener(exportBtn, 'click', exportTable.open);
+			}
+
+
+			//
+			//
+			// Init row number control and rows selection
 			//
 			//
 
@@ -82,7 +105,6 @@ var report = {
 			var isUnknownTotalRows = false;
 			var numberOfRowsInTable = 0;
 
-			
 			if (reportElementType == 'table' || isLogDetail) {
 				
 				report.isTableOrLogDetailReportElement = true;
@@ -94,18 +116,19 @@ var report = {
 
 				// Ignore totalRows value if isUnknownTotalRows is true. In this case we allow to set any row number
 				// because the total rows number is not accurate.
-				
-				if (o.totalRows > 0 || isUnknownTotalRows) {
 
-					report.rowNumbers.init(
-						shortReportElementId,
-						reportElementType,
-						o.startingRow,
-						o.endingRow,
-						o.numberOfRows,
-						o.totalRows,
-						isUnknownTotalRows,
-						numberOfRowsInTable);
+				report.rowNumbers.init(
+					shortReportElementId,
+					reportElementType,
+					o.startingRow,
+					o.endingRow,
+					o.numberOfRows,
+					o.totalRows,
+					isUnknownTotalRows,
+					numberOfRowsInTable);
+
+				
+				if (o.totalRows > 0 || numberOfRowsInTable > 0) {
 
 					//
 					// init row selection
@@ -152,17 +175,17 @@ var report = {
 			}
 			else if (reportElementType == 'session_page_paths') {
 				
-				if (o.totalRows > 10) {
-					report.rowNumbers.init(
-						shortReportElementId,
-						reportElementType,
-						1,
-						o.endingRow,
-						o.endingRow,
-						o.totalRows,
-						isUnknownTotalRows,
-						numberOfRowsInTable);
-				}
+//				if (o.totalRows > 10) {}
+				report.rowNumbers.init(
+					shortReportElementId,
+					reportElementType,
+					1,
+					o.endingRow,
+					o.endingRow,
+					o.totalRows,
+					isUnknownTotalRows,
+					numberOfRowsInTable);
+
 				
 				YE.addListener(shortReportElementId + ':page_path_field', 'keypress', newReport.setPagePathViaKey);
 				YE.addListener(shortReportElementId + ':show_path_btn', 'click', newReport.setPagePathViaButton);
@@ -393,8 +416,6 @@ var report = {
 		var isEmailReportBtn = !isCalendar && permissions.sendReportByEmail;
 		var isSaveReportChangesBtn = !isCalendar && permissions.saveReportChanges;
 		var isSaveAsNewReportBtn = !isCalendar && permissions.saveAsNewReport;
-		
-		// var isDatabaseInfoBtn = !isCalendar && permissions.databaseInfo;
 		var isUpdateDatabaseBtn = !isCalendar && permissions.updateDatabase;
 		var isBuildDatabaseBtn = !isCalendar && permissions.buildDatabase;
 
@@ -460,12 +481,6 @@ var report = {
 				YE.addListener('reports_toolbar:drop_down:save_as_new_report_btn', 'click', saveAsNewReport.open);
 			}
 			
-			/*
-			if (isDatabaseInfoBtn) {
-				YE.addListener('reports_toolbar:drop_down:database_info_btn', 'click', databaseInfo.open);
-			}
-			*/
-			
 			if (isUpdateDatabaseBtn) {
 				YE.addListener('reports_toolbar:drop_down:update_database_btn', 'click', databaseUtil.updateDatabase);
 			}
@@ -481,6 +496,11 @@ var report = {
 		else {
 			report.toolsBtn.disableAndIgnore();
 		}
+
+		// Hide reports toolbar in Calendar
+		if (isCalendar) {
+			util.hideEV('reports_toolbar');
+		}
 		
 		// Init help button
 		util.helpWindow.init('?dp+docs.user_guide.index');
@@ -637,17 +657,15 @@ var report = {
 					}
 				}
 				
-				if (isColumnInfo) {
+//				if (isColumnInfo) {
 					
 					// The row contains at least one column with a columnInfo.
 					// Show columnInfo icon and add columnInfo event
-					util.hideE(shortReportElementId + ':index_col:space');
-					util.showE(shortReportElementId + ':index_col:show_column_info_img');
-					
-					var indexThElementId = shortReportElementId + ':index_col:show_column_info_btn';
-					
-					YE.addListener(indexThElementId, 'click', report.columns.columnActor);
-				}
+//					util.hideE(shortReportElementId + ':index_col:space');
+//					util.showE(shortReportElementId + ':index_col:show_column_info_img');
+//					var indexThElementId = shortReportElementId + ':index_col:show_column_info_btn';
+//					YE.addListener(indexThElementId, 'click', report.columns.columnActor);
+//				}
 			}
 		},
 		
@@ -673,18 +691,26 @@ var report = {
 	},
 
 	rowNumbers: {
-		
+
+		validator: null,
 		sequence: [10,20,50,100,200,500],
-		
-		setRowNumber: function() {
-			
+
+		setRows: function(evt) {
+
 			var id = this.id;
 			var dat = id.split(':');
 			var shortReportElementId = dat[0];
-			var startingRow = 1;
-			var endingRow = this.options[this.selectedIndex].value;
-			var numberOfRows = endingRow;
-			newReport.setRowNumber(shortReportElementId, startingRow, endingRow, numberOfRows);
+			var endingRow = parseInt(dat[2]);
+
+			if (endingRow != -1) {
+				var startingRow = 1;
+				var numberOfRows = endingRow;
+				newReport.setRowNumber(shortReportElementId, startingRow, endingRow, numberOfRows);
+			}
+			else {
+				// Show custom row range panel
+				report.rowNumbers.showCustomPanel(shortReportElementId);
+			}
 		},
 		
 		setRowRange: function() {
@@ -692,7 +718,7 @@ var report = {
 			var id = this.id;
 			var dat = id.split(':');
 			var shortReportElementId = dat[0];
-			var isNext = (dat[1].indexOf('next_rows_btn') != -1);
+			var isNext = (dat[1].indexOf('next_rows') != -1);
 
 			var o = reportInfo.reportElements[util.h(shortReportElementId)];
 			var startingRow = o.startingRow;
@@ -712,7 +738,6 @@ var report = {
 			var newStartingRow = -1;
 			var newEndingRow = -1;
 
-
 			if (isNext &&
 				((!isUnknownTotalRows && endingRow < totalRows) ||
 				(isUnknownTotalRows && numberOfRowsInTable > 0))) {
@@ -726,13 +751,23 @@ var report = {
 					newEndingRow = totalRows;
 				}
 			}
-			else if (startingRow != -1) {
+			else if (startingRow != 1) {
 
 				// Go to previous rows
 				newStartingRow = (startingRow - numberOfRows >= 1) ? startingRow - numberOfRows : 1;
 				newEndingRow = startingRow - 1;
 			}
 
+//			util.showObject({
+//				startingRow: startingRow,
+//				endingRow: endingRow,
+//				numberOfRows: numberOfRows,
+//				totalRows: totalRows,
+//				newStartingRow: newStartingRow,
+//				newEndingRow: newEndingRow
+//			});
+//
+
 			// Simply ignore clicks if we didn't set a new starting row and ending row
 			if (newStartingRow != -1) {
 				newReport.setRowNumber(shortReportElementId, newStartingRow, newEndingRow, numberOfRows);
@@ -740,136 +775,253 @@ var report = {
 		},
 			
 		setCustomRowRange: function() {
+
+			var validator = report.rowNumbers.validator;
+			validator.reset();
 			
 			var calleeId = this.id;
 			var dat = calleeId.split(':');
 			var shortReportElementId = dat[0];
-			
-			var startingRow = util.getF(shortReportElementId + ':custom_row_range:starting_row');
-			var endingRow = util.getF(shortReportElementId + ':custom_row_range:ending_row');
-			
-			var isValidRange = false;
-			
-			if (util.isInteger(startingRow) && util.isInteger(endingRow)) {
-				
+
+			var o = reportInfo.reportElements[util.h(shortReportElementId)];
+			var reportElementType = o.reportElementType;
+			var totalRows = o.totalRows;
+			var isUnknownTotalRows = false;
+
+			if (reportElementType == 'log_detail' && o.hasOwnProperty('isUnknownTotalRows')) {
+				isUnknownTotalRows = o.isUnknownTotalRows;
+			}
+
+			var startingRow = validator.isInteger(shortReportElementId + ':custom_row_range:starting_row', 1);
+			var endingRow = validator.isInteger(shortReportElementId + ':custom_row_range:ending_row', 1);
+
+			// Check if values are in range
+			if (util.isInteger(startingRow, 1) && util.isInteger(endingRow, 1)) {
+
 				startingRow = parseInt(startingRow, 10);
 				endingRow = parseInt(endingRow, 10);
 
-				var o = reportInfo.reportElements[util.h(shortReportElementId)];
-
-				var reportElementType = o.reportElementType;
-				var totalRows = o.totalRows;
-				var isUnknownTotalRows = false;
-
-				if (reportElementType == 'log_detail' && o.hasOwnProperty('isUnknownTotalRows')) {
-					isUnknownTotalRows = o.isUnknownTotalRows;
+				if (startingRow > endingRow) {
+					validator.isCustom(shortReportElementId + ':custom_row_range:starting_row',
+							langVar('lang_stats.row_numbers.invalid_row_numbers_message'));
+				}
+				// Allow endingRow to exceed totalRows if total rows is an estimate.
+				else if (!isUnknownTotalRows && endingRow > totalRows) {
+					validator.isCustom(shortReportElementId + ':custom_row_range:ending_row',
+							langVar('lang_stats.row_numbers.invalid_row_numbers_message'));
 				}
 
-				// Allow endingRow to exceed totalRows if total rows is an estimate.
 				if (startingRow > 0 && startingRow <= endingRow && (endingRow <= totalRows || isUnknownTotalRows)) {
 					isValidRange = true;
 				}
 			}
-			
-			if (isValidRange) {
-				
+
+			if (validator.allValid()) {
 				var numberOfRows = endingRow - startingRow + 1;
 				newReport.setRowNumber(shortReportElementId, startingRow, endingRow, numberOfRows);
 			}
-			else {
-				alert(langVar('lang_stats.row_numbers.invalid_row_numbers_message'));
-			}
-		},
-		
-		toggleCustomRowRange: function() {
+
 			
-			// alert('toggleCustomRowRange()');
-			var calleeId = this.id;
-			var dat = calleeId.split(':');
-			var shortReportElementId = dat[0];
+//			var startingRow = util.getF(shortReportElementId + ':custom_row_range:starting_row');
+//			var endingRow = util.getF(shortReportElementId + ':custom_row_range:ending_row');
 			
-			var element = util.getE(shortReportElementId + ':custom_row_range:panel');
-			var showCustomRange = (element.style.display == 'none');
-			element.style.display = showCustomRange ? 'block' : 'none';
-
-			if (showCustomRange) {
-				util.focusE(shortReportElementId + ':custom_row_range:starting_row');
-			}
-		},
-
-		init: function(shortReportElementId, reportElementType, startingRow, endingRow, numberOfRows, totalRows, isUnknownTotalRows, numberOfRowsInTable) {
-
-			var YE = YAHOO.util.Event;
-			var sequence = report.rowNumbers.sequence;
-//			var theRows = [{value:10, label:10},
-//							{value:20, label:20},
-//							{value:50, label:50},
-//							{value:100, label:100},
-//							{value:200, label:200},
-//							{value:500, label:500}];
-
-			var theRows = [];
-			var defaultNumberOfRows = '';
-
-//			for (var i = 0; i < theRows.length; i++) {
-//				if (theRows[i].value == numberOfRows) {
-//					defaultNumberOfRows = numberOfRows;
-//					break;
+//			var isValidRange = false;
+//
+//			if (util.isInteger(startingRow) && util.isInteger(endingRow)) {
+//
+//				startingRow = parseInt(startingRow, 10);
+//				endingRow = parseInt(endingRow, 10);
+//
+//				// Allow endingRow to exceed totalRows if total rows is an estimate.
+//				if (startingRow > 0 && startingRow <= endingRow && (endingRow <= totalRows || isUnknownTotalRows)) {
+//					isValidRange = true;
 //				}
 //			}
+			
+//			if (isValidRange) {
+//
+//				var numberOfRows = endingRow - startingRow + 1;
+//				newReport.setRowNumber(shortReportElementId, startingRow, endingRow, numberOfRows);
+//			}
+//			else {
+//				alert(langVar('lang_stats.row_numbers.invalid_row_numbers_message'));
+//			}
+		},
+		
+		showCustomPanel: function(shortReportElementId) {
 
-			var rowNumberInSequence;
+			report.rowNumbers.validator = new util.Validator();
 
-			for (var i = 0, sequenceLen = sequence.length; i < sequenceLen; i++) {
+			var YD = YAHOO.util.Dom;
+			var element = util.getE(shortReportElementId + ':custom_row_range:panel');
+			var rowsBtnRegion = YD.getRegion(shortReportElementId + ':rows:btn');
+			var viewportWidth = YD.getViewportWidth();
+//			util.showObject(rowsBtnRegion);
+			element.style.top = rowsBtnRegion.bottom + 'px';
+			element.style.right = (viewportWidth - rowsBtnRegion.right) + 'px';
+			element.style.display = 'block';
 
-				rowNumberInSequence = sequence[i];
+			util.focusE(shortReportElementId + ':custom_row_range:starting_row');
+		},
 
-				if (rowNumberInSequence <  totalRows) {
-					theRows[i] = {value:rowNumberInSequence, label:rowNumberInSequence};
+		closeCustomPanel: function(evt) {
 
-					// Set default selected row number
-					if (rowNumberInSequence == numberOfRows) {
-						defaultNumberOfRows = numberOfRows;
-					}
+			var id = this.id;
+			var dat = id.split(':');
+			var shortReportElementId = dat[0];
+
+			util.hideE(shortReportElementId + ':custom_row_range:panel');
+		},
+
+//		setButtonSate: function(
+//			shortReportElementId,
+//			startingRow,
+//			endingRow,
+//			totalRows,
+//			isUnknownTotalRows,
+//			numberOfRowsInTable) {
+//
+//			var prevBtn = util.getE(shortReportElementId + ':prev_rows:btn');
+//			var nextBtn = util.getE(shortReportElementId + ':next_rows:btn');
+//
+//			// prevBtn.disabled = startingRow
+//
+//
+//
+//		},
+
+		init: function(shortReportElementId,
+			reportElementType,
+			startingRow,
+			endingRow,
+			numberOfRows,
+			totalRows,
+			isUnknownTotalRows,
+			numberOfRowsInTable) {
+
+			var YE = YAHOO.util.Event;
+
+			// Row number controls are disabled by default
+
+			//
+			// Enable previous next rows buttons
+			//
+
+			if (reportElementType !== 'session_page_paths' &&
+				(totalRows > 0 || isUnknownTotalRows)) {
+
+
+				if (startingRow > 1) {
+
+					var preRowsBtn = util.getE(shortReportElementId + ':prev_rows:btn');
+					preRowsBtn.disabled = false;
+					preRowsBtn.className = 'btn-60';
+
+					YE.addListener(preRowsBtn, 'click', report.rowNumbers.setRowRange);
 				}
-				else {
 
-					//Add 'All Rows' number if appropriate
-					var maxRowNumber = sequence[sequenceLen - 1];
+				if (endingRow < totalRows || isUnknownTotalRows) {
 
-					if (totalRows <= maxRowNumber) {
-						theRows[i] = {value:totalRows, label:totalRows};
+					var nextRowsBtn = util.getE(shortReportElementId + ':next_rows:btn');
+					nextRowsBtn.disabled = false;
+					nextRowsBtn.className = 'btn-60';
 
-						// Set default selected row number
-						if (totalRows == numberOfRows) {
-							defaultNumberOfRows = totalRows;
+					YE.addListener(nextRowsBtn, 'click', report.rowNumbers.setRowRange);
+				}
+			}
+
+
+			//
+			// Handle drop down
+			//
+
+			if (totalRows > 1 || isUnknownTotalRows) {
+
+				var rowsBtn = util.getE(shortReportElementId + ':rows:btn');
+				rowsBtn.disabled = false;
+				rowsBtn.className = 'btn-60';
+
+				var sequence = report.rowNumbers.sequence;
+				var theRows = [];
+				var rowNumberInSequence;
+
+				for (var i = 0, sequenceLen = sequence.length; i < sequenceLen; i++) {
+
+					rowNumberInSequence = sequence[i];
+
+					if (rowNumberInSequence <  totalRows) {
+
+						theRows[i] = {value:rowNumberInSequence, label:rowNumberInSequence};
+					}
+					else {
+
+						// Add 'All Rows' number if appropriate
+						var maxRowNumber = sequence[sequenceLen - 1];
+
+						if (totalRows <= maxRowNumber) {
+							theRows[i] = {value:totalRows, label:totalRows};
 						}
+
+						break;
 					}
-
-					break;
 				}
+
+				// Add Custom entry
+				theRows[theRows.length] = {value:-1, label:langVar('lang_stats.btn.custom')};
+
+				// Create rows drop down
+				var rowsDropDownContainer = util.getE(shortReportElementId + ':rows:menu');
+
+				var rowsDropDownElement = report.rowNumbers.getRowsDropDownElement(shortReportElementId, theRows);
+				util.chainE(rowsDropDownContainer, rowsDropDownElement);
+
+				YE.addListener(shortReportElementId + ':custom_row_range:apply_btn', 'click', report.rowNumbers.setCustomRowRange);
+				YE.addListener([shortReportElementId + ':custom_row_range:close_btn', shortReportElementId + ':next_rows:btn'], 'click', report.rowNumbers.closeCustomPanel);
+
+
+				// Init drop down navigation
+				var navInfo = {
+					containerId: (shortReportElementId + '_table_nav'),
+					btnClassName: 'btn-60',
+					btnActiveClassName: 'btn-60',
+					menuBaseIds: [
+					(shortReportElementId + ':export'),
+					(shortReportElementId + ':prev_rows'),
+					(shortReportElementId + ':next_rows'),
+					(shortReportElementId + ':rows')]
+				};
+
+				new util.NavGroup(navInfo);
+			}
+		},
+
+		getRowsDropDownElement: function(shortReportElementId, theRows) {
+
+			// var menuId = shortReportElementId + ':rows_menu';
+			var ul = util.createE('ul', {className:'drop-down-10 drop-down-10-inline'});
+			var rowsItem;
+			var li;
+			var a;
+			var aText;
+
+			for (var i = 0, theRowsLen = theRows.length; i < theRowsLen; i++) {
+
+				rowsItem = theRows[i];
+				li = util.createE('li', {id:shortReportElementId + ':rows_list:' + rowsItem.value});
+				a = util.createE('a', {href:'javascript:;'});
+				aText = util.createT(rowsItem.label);
+				util.chainE(ul, [li, [a, aText]]);
+
+				YAHOO.util.Event.addListener(li, 'click', report.rowNumbers.setRows);
 			}
 
-			if (defaultNumberOfRows == '') {
-				// No number of rows which matches the default list.
-				// Add ndash as first and active row number list item
-				theRows.splice(0, 0, {value:'', label:'\u2013'});
-			}
-
-			// Populate select element.
-			util.populateSelect(shortReportElementId + ':row_numbers', theRows, 'value', 'label', defaultNumberOfRows);
-
-			YE.addListener(shortReportElementId + ':row_numbers', 'change', report.rowNumbers.setRowNumber);
-			YE.addListener([shortReportElementId + ':prev_rows_btn', shortReportElementId + ':next_rows_btn'], 'click', report.rowNumbers.setRowRange);
-			YE.addListener(shortReportElementId + ':toggle_custom_row_range', 'click', report.rowNumbers.toggleCustomRowRange);
-			YE.addListener(shortReportElementId + ':custom_row_range:btn', 'click', report.rowNumbers.setCustomRowRange);
+			return ul;
 		}
 	},
 	
 	
 	rowSelection: {
-		
-		
+
 		// Note, row selction handles row selection, zoom item selection and breakdown links and page links.
 		// A click on a page link (anchor, img or span element) should be simply ignored.
 		
@@ -994,7 +1146,7 @@ var report = {
 		
 		resetZoomItems: function() {
 			
-			// Resests and deselects all zoomed items. It is invoked from zoom control
+			// Resets and deselects all zoomed items. It is invoked from zoom control
 			
 			var rowsDb = report.rowSelection.rowsDb;
 			
